@@ -418,10 +418,8 @@ async def django_instance_to_redis_params(
         if not django_field.__class__.__name__.endswith('Rel'):
             django_field_name = django_field.name
             allowed = True
-            print(exclude_fields)
             if exclude_fields:
-                allowed = (django_field.name not in exclude_fields)
-                print(allowed, django_field.name, exclude_fields)
+                allowed = (django_field.name in exclude_fields)
             if allowed:
                 if django_field.name not in ['id', 'pk']:
                     redis_param = await django_instance_field_to_redis_value(
