@@ -464,7 +464,7 @@ class RedisRoot:
                 django_field_name = django_field.name
                 allowed = True
                 if exclude_fields:
-                    allowed = (django_field.name not in exclude_fields)
+                    allowed = (django_field.name in exclude_fields)
                 if allowed:
                     if django_field.name in ['id', 'pk']:
                         django_field_name = 'django_id'
@@ -1104,6 +1104,7 @@ class RedisModel:
         self.__model_data__['fields'] = fields
 
     def _fill_fields_values(self, field_values_dict):
+        print('_fill_fields_values', field_values_dict)
         for name, value in field_values_dict.items():
             fields = self.__model_data__['fields']
             if name in fields.keys():
@@ -1121,6 +1122,7 @@ class RedisModel:
         for field_name, field in fields.items():
             if not field_name.startswith('__'):
                 try:
+                    print(field_name, field.value)
                     cleaned_value = field.clean()
                     if instance_key not in cleaned_fields.keys():
                         cleaned_fields[instance_key] = {}
